"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DestinationFiltersPlugin = void 0;

var _analyticsReactNative = require("@segment/analytics-react-native");

var tsub = _interopRequireWildcard(require("@segment/tsub"));

var _clone = _interopRequireDefault(require("clone"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const WORKSPACE_DESTINATION_FILTER_KEY = '';
/**
 * Adds processing for Destination Filters
 * (https://segment.com/docs/connections/destinations/destination-filters/)
 * to work on device mode destinations
 */

class DestinationFiltersPlugin extends _analyticsReactNative.UtilityPlugin {
  constructor(destination) {
    super();

    _defineProperty(this, "type", _analyticsReactNative.PluginType.before);

    _defineProperty(this, "key", void 0);

    _defineProperty(this, "filtersUnsubscribe", void 0);

    _defineProperty(this, "filter", void 0);

    this.key = destination;
  }

  addToPlugin(plugin) {
    if (plugin.type === _analyticsReactNative.PluginType.destination) {
      const destination = plugin;
      destination.add(new DestinationFiltersPlugin(destination.key));
    }
  }

  configure(analytics) {
    var _analytics$filters$ge, _this$filtersUnsubscr;

    super.configure(analytics);

    if (this.key === undefined) {
      // We watch for new destination plugins being added to inject a
      // destination filter instance for them
      analytics.onPluginLoaded(this.addToPlugin); // We also inject an instance for each plugin already loaded

      analytics.getPlugins(_analyticsReactNative.PluginType.destination).forEach(this.addToPlugin);
    }

    const key = this.key ?? WORKSPACE_DESTINATION_FILTER_KEY;
    this.filter = (_analytics$filters$ge = analytics.filters.get()) === null || _analytics$filters$ge === void 0 ? void 0 : _analytics$filters$ge[key];
    (_this$filtersUnsubscr = this.filtersUnsubscribe) === null || _this$filtersUnsubscr === void 0 ? void 0 : _this$filtersUnsubscr.call(this);
    this.filtersUnsubscribe = analytics.filters.onChange(filters => {
      this.filter = filters === null || filters === void 0 ? void 0 : filters[key];
    });
  }

  execute(event) {
    if (this.filter === undefined) {
      return event;
    }

    const {
      matchers,
      transformers
    } = this.filter;
    let transformedEvent;

    for (let i = 0; i < matchers.length; i++) {
      if (tsub.matches(event, matchers[i])) {
        // We have to deep clone the event as the tsub transform modifies the event in place
        if (transformedEvent === undefined) {
          transformedEvent = (0, _clone.default)(event);
        }

        const newEvent = tsub.transform(transformedEvent, transformers[i]);

        if (newEvent === undefined || newEvent === null) {
          return undefined;
        }

        transformedEvent = newEvent;
      }
    }

    return transformedEvent ?? event;
  }

}

exports.DestinationFiltersPlugin = DestinationFiltersPlugin;
//# sourceMappingURL=DestinationFilters.js.map